<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

if ( class_exists( 'WP_Customize_Control' ) ) {   

    class WP_Customize_Category_Control extends WP_Customize_Control {
        /**
         * Render the control's content.
         *
         * @since 3.4.0
         */
        public function render_content() {
            $dropdown = wp_dropdown_categories(
                array(
                    'name'              => '_customize-dropdown-categories-' . $this->id,
                    'echo'              => 0,
                    'show_option_none'  => esc_html__( '&mdash; Select &mdash;', 'sarahlite' ),
                    'option_none_value' => '0',
                    'selected'          => $this->value(),
                )
            );
    
            // Hackily add in the data link parameter.
            $dropdown = str_replace( '<select', '<select ' . $this->get_link(), $dropdown );
    
            printf(
                '<label class="customize-control-select"><span class="customize-control-title">%s</span> %s</label>',
                $this->label,
                $dropdown
            );
        }
    }
}

function sarahlite_sanitize_checkbox( $checked ) {	
	return ( ( isset( $checked ) && true == $checked ) ? true : false );
}

function sarahlite_sanitize_number_absint( $number, $setting ) {
	// Ensure $number is an absolute integer (whole number, zero or greater).
	$number = absint( $number );
	// If the input is an absolute integer, return it; otherwise, return the default
	return ( $number ? $number : $setting->default );
}

function sarahlite_sanitize_select( $input, $setting ) {
	// Ensure input is a slug.
	$input = sanitize_key( $input );
	// Get list of choices from the control associated with the setting.
	$choices = $setting->manager->get_control( $setting->id )->choices;
	// If the input is a valid key, return it; otherwise, return the default.
	return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
}

/** Sarah - Customizer - Add Settings */
function sarahlite_register_theme_customizer( $wp_customize ) {
    # SECTIONS
    $wp_customize->add_section( 'sarahlite_new_section_featured_posts' , array(
		'title' => __( 'Featured Posts Slider', 'sarahlite' )
	) );

    $wp_customize->add_section( 'sarahlite_new_section_promo_boxes', array(
   		'title' => __( 'Promo Boxes', 'sarahlite' )
	) );
 
    $wp_customize->add_section( 'sarahlite_new_section_blog', array(
   		'title' => __( 'Blog Settings', 'sarahlite' )
	) );

    $wp_customize->add_section( 'sarahlite_new_section_social_media', array(
   		'title' => __( 'Social Media Links', 'sarahlite' )
	) );

    $wp_customize->add_section( 'sarahlite_new_section_footer', array(
   		'title' => __( 'Site Footer', 'sarahlite' )
	) );

    # Header Options
    $wp_customize->add_setting( 'sarahlite_site_brading_display_tagline', array( 'default' => false, 'sanitize_callback' => 'sarahlite_sanitize_checkbox' ) );
    $wp_customize->add_setting( 'sarahlite_logo_padding_top', array( 'default' => '50', 'sanitize_callback' => 'sarahlite_sanitize_number_absint' ) );
    $wp_customize->add_setting( 'sarahlite_logo_padding_bottom', array( 'default' => '50', 'sanitize_callback' => 'sarahlite_sanitize_number_absint' ) );

    $wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'sarahlite_site_brading_display_tagline',
			array(
				'label'      => __( 'Display Tagline?', 'sarahlite' ),
				'section'    => 'title_tagline',
				'type'		 => 'checkbox'
			)
		)
	);
    $wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'sarahlite_logo_padding_top',
            array(
                'type' => 'number',
                'label' => __( 'Logo: Padding Top', 'sarahlite' ),
                'section' => 'title_tagline'
            )
    ));

    $wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'sarahlite_logo_padding_bottom',
			array(
                'type' => 'number',
                'label' => __( 'Logo: Padding Bottom', 'sarahlite' ),
                'section' => 'title_tagline'
            )
    ));
    
    /**
     * Featured Posts Slider
     */
    $wp_customize->add_setting( 'sarahlite_featured_slider', array( 'sanitize_callback' => 'absint' ) );
	$wp_customize->add_setting( 'sarahlite_featured_cat', array( 'sanitize_callback' => 'absint' ) );
	$wp_customize->add_setting( 'sarahlite_featured_id', array( 'sanitize_callback' => 'wp_kses_post' ) );
	$wp_customize->add_setting( 'sarahlite_featured_slider_slides', array( 'default' => '3', 'sanitize_callback' => 'absint' ) );
    
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'sarahlite_featured_slider',
			array(
				'label'      => __( 'Enable Featured Slider', 'sarahlite' ),
				'section'    => 'sarahlite_new_section_featured_posts',
				'type'		 => 'checkbox'
			)
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Category_Control(
			$wp_customize,
			'sarahlite_featured_cat',
			array(
				'label'    => __( 'Select Featured Category', 'sarahlite' ),
				'section'  => 'sarahlite_new_section_featured_posts'
			)
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'sarahlite_featured_id',
			array(
				'label'      => __( 'Select featured post/page IDs', 'sarahlite' ),
				'section'    => 'sarahlite_new_section_featured_posts',
				'type'		 => 'textarea',
                'description'=> __( 'This will override the above category.', 'sarahlite' ),
			)
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'sarahlite_featured_slider_slides',
			array(
				'label'      => __( 'Amount of Slides', 'sarahlite' ),
				'section'    => 'sarahlite_new_section_featured_posts',
				'type'		 => 'number',
			)
		)
	);

    /**
     * Promo Boxes
     */
    $wp_customize->add_setting( 'sarahlite_promobox_show', array( 'default' => false, 'sanitize_callback' => 'sarahlite_sanitize_checkbox' ) );
    $wp_customize->add_setting( 'sarahlite_promobox_one_title', array( 'default' => '', 'sanitize_callback' => 'sanitize_text_field' ) );
    $wp_customize->add_setting( 'sarahlite_promobox_one_link', array( 'default' => '', 'sanitize_callback' => 'esc_url_raw' ) );
    $wp_customize->add_setting( 'sarahlite_promobox_one_image', array( 'default' => '', 'sanitize_callback' => 'esc_url_raw' ) );
    $wp_customize->add_setting( 'sarahlite_promobox_two_title', array( 'default' => '', 'sanitize_callback' => 'sanitize_text_field' ) );
    $wp_customize->add_setting( 'sarahlite_promobox_two_link', array( 'default' => '', 'sanitize_callback' => 'esc_url_raw' ) );
    $wp_customize->add_setting( 'sarahlite_promobox_two_image', array( 'default' => '', 'sanitize_callback' => 'esc_url_raw' ) );
    $wp_customize->add_setting( 'sarahlite_promobox_three_title', array( 'default' => '', 'sanitize_callback' => 'sanitize_text_field' ) );
    $wp_customize->add_setting( 'sarahlite_promobox_three_link', array( 'default' => '', 'sanitize_callback' => 'esc_url_raw' ) );
    $wp_customize->add_setting( 'sarahlite_promobox_three_image', array( 'default' => '', 'sanitize_callback' => 'esc_url_raw' ) );
    
    
    $wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'sarahlite_promobox_show',
			array(
				'label'      => __( 'Show ?', 'sarahlite' ),
				'section'    => 'sarahlite_new_section_promo_boxes',
				'type'		 => 'checkbox'
			)
		)
	);
    
    $wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'sarahlite_promobox_one_title',
			array(
				'label'      => __( 'Box 1 # Title', 'sarahlite' ),
				'section'    => 'sarahlite_new_section_promo_boxes'
			)
		)
	);
    
    $wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'sarahlite_promobox_one_link',
			array(
				'label'      => __( 'Box 1 # URL', 'sarahlite' ),
				'section'    => 'sarahlite_new_section_promo_boxes'
			)
		)
	);
    
    $wp_customize->add_control(
		new WP_Customize_Image_Control(
			$wp_customize,
			'sarahlite_promobox_one_image',
			array(
				'label'      => __( 'Box 1 # Image', 'sarahlite' ),
				'section'    => 'sarahlite_new_section_promo_boxes'
			)
		)
	);
    
    $wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'sarahlite_promobox_two_title',
			array(
				'label'      => __( 'Box 2 # Title', 'sarahlite' ),
				'section'    => 'sarahlite_new_section_promo_boxes'
			)
		)
	);
    
    $wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'sarahlite_promobox_two_link',
			array(
				'label'      => __( 'Box 2 # URL', 'sarahlite' ),
				'section'    => 'sarahlite_new_section_promo_boxes'
			)
		)
	);
    
    $wp_customize->add_control(
		new WP_Customize_Image_Control(
			$wp_customize,
			'sarahlite_promobox_two_image',
			array(
				'label'      => __( 'Box 2 # Image', 'sarahlite' ),
				'section'    => 'sarahlite_new_section_promo_boxes'
			)
		)
	);
    
    $wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'sarahlite_promobox_three_title',
			array(
				'label'      => __( 'Box 3 # Title', 'sarahlite' ),
				'section'    => 'sarahlite_new_section_promo_boxes'
			)
		)
	);
    
    $wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'sarahlite_promobox_three_link',
			array(
				'label'      => __( 'Box 3 # URL', 'sarahlite' ),
				'section'    => 'sarahlite_new_section_promo_boxes'
			)
		)
	);
    
    $wp_customize->add_control(
		new WP_Customize_Image_Control(
			$wp_customize,
			'sarahlite_promobox_three_image',
			array(
				'label'      => __( 'Box 3 # Image', 'sarahlite' ),
				'section'    => 'sarahlite_new_section_promo_boxes'
			)
		)
	);

    /**
     * Blog Settings
     */    
    $wp_customize->add_setting( 'sarahlite_blog_layout', array( 'default' => 'blog-2cols-grid', 'sanitize_callback' => 'sarahlite_sanitize_select' ) );
    $wp_customize->add_setting( 'azt_blog_hide_sidebar', array( 'default' => false, 'sanitize_callback' => 'sarahlite_sanitize_checkbox' ) );
    
    $wp_customize->add_setting( 'sarahlite_archive_layout', array( 'default' => 'blog-2cols-grid', 'sanitize_callback' => 'sarahlite_sanitize_select' ) );
    $wp_customize->add_setting( 'azt_archive_hide_sidebar', array( 'default' => false, 'sanitize_callback' => 'sarahlite_sanitize_checkbox' ) );
    
    $wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'sarahlite_blog_layout',
			array(
				'label' => __( 'Blog Layout', 'sarahlite' ),
				'section' => 'sarahlite_new_section_blog',
				'type' => 'radio',
				'choices' => array(
					'blog-standard' => __( 'Standard Layout', 'sarahlite' ),
					'blog-2cols-grid' => __( '2 Cols Grid', 'sarahlite' )
				)
			)
		)
	);
    
    $wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'azt_blog_hide_sidebar',
			array(
				'label' => __( 'Hide sidebar on blog page?', 'sarahlite' ),
				'section' => 'sarahlite_new_section_blog',
				'type' => 'checkbox'
			)
		)
	);
    
    $wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'sarahlite_archive_layout',
			array(
				'label' => __( 'Archive Layout', 'sarahlite' ),
				'section' => 'sarahlite_new_section_blog',
				'type' => 'radio',
				'choices' => array(
					'blog-standard' => __( 'Standard Layout', 'sarahlite' ),
					'blog-2cols-grid' => __( '2 Cols Grid', 'sarahlite' )
				)
			)
		)
	);
    $wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'azt_archive_hide_sidebar',
			array(
				'label' => __( 'Hide sidebar on archive page?', 'sarahlite' ),
				'section' => 'sarahlite_new_section_blog',
				'type' => 'checkbox'
			)
		)
	);

    # Social media 
    $wp_customize->add_setting( 'sarahlite_facebook_url', array( 'sanitize_callback' => 'esc_url_raw' ) );
    $wp_customize->add_setting( 'sarahlite_twitter_url', array( 'sanitize_callback' => 'esc_url_raw' ) );
    $wp_customize->add_setting( 'sarahlite_instagram_url', array( 'sanitize_callback' => 'esc_url_raw' ) );
    $wp_customize->add_setting( 'sarahlite_pinterest_url', array( 'sanitize_callback' => 'esc_url_raw' ) );
    $wp_customize->add_setting( 'sarahlite_youtube_url', array( 'sanitize_callback' => 'esc_url_raw' ) );
    $wp_customize->add_setting( 'sarahlite_soundcloud_url', array( 'sanitize_callback' => 'esc_url_raw' ) );    
    $wp_customize->add_setting( 'sarahlite_vimeo_url', array( 'sanitize_callback' => 'esc_url_raw' ) );
    
    $wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'sarahlite_facebook_url',
			array(
				'label'      => __( 'Facebook URL', 'sarahlite' ),
				'section'    => 'sarahlite_new_section_social_media'
			)
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'sarahlite_twitter_url',
			array(
				'label'      => __( 'Twitter URL', 'sarahlite' ),
				'section'    => 'sarahlite_new_section_social_media'
			)
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'sarahlite_instagram_url',
			array(
				'label'      => __( 'Instagram URL', 'sarahlite' ),
				'section'    => 'sarahlite_new_section_social_media'
			)
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'sarahlite_pinterest_url',
			array(
				'label'      => __( 'Pinterest URL', 'sarahlite' ),
				'section'    => 'sarahlite_new_section_social_media'
			)
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'sarahlite_youtube_url',
			array(
				'label'      => __( 'Youtube URL', 'sarahlite' ),
				'section'    => 'sarahlite_new_section_social_media'
			)
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'sarahlite_soundcloud_url',
			array(
				'label'      => __( 'Soundcloud URL', 'sarahlite' ),
				'section'    => 'sarahlite_new_section_social_media'
			)
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'sarahlite_vimeo_url',
			array(
				'label'      => __( 'Vimeo URL', 'sarahlite' ),
				'section'    => 'sarahlite_new_section_social_media'
			)
		)
	);

    # Colors
    $wp_customize->add_setting( 'sarahlite_primary_color', array(
        'default' => '#333',
        'sanitize_callback' => 'sanitize_hex_color'
    ));

    $wp_customize->add_setting( 'sarahlite_body_color', array(
        'default' => '#555',
        'sanitize_callback' => 'sanitize_hex_color'
    ));

    $wp_customize->add_setting( 'sarahlite_meta_color', array(
        'default' => '#999',
        'sanitize_callback' => 'sanitize_hex_color'
    ));

    $wp_customize->add_setting( 'sarahlite_accent_color', array(
        'default' => '#f37e7e',
        'sanitize_callback' => 'sanitize_hex_color'
    ));
    
    $wp_customize->add_setting( 'sarahlite_border_color', array(
        'default' => '#ddd',
        'sanitize_callback' => 'sanitize_hex_color'
    ));

    $wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'sarahlite_primary_color',
			array(
				'label' => __( 'Primary Color', 'sarahlite' ),
				'section' => 'colors'
			)
		)
	);

    $wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'sarahlite_body_color',
			array(
				'label' => __( 'Body Color', 'sarahlite' ),
				'section' => 'colors'
			)
		)
	);

    $wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'sarahlite_accent_color',
			array(
				'label' => __( 'Accent Color', 'sarahlite' ),
				'section' => 'colors'
			)
		)
	);
    
    $wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'sarahlite_meta_color',
			array(
				'label' => __( 'Meta Color', 'sarahlite' ),
				'section' => 'colors'
			)
		)
	);

    $wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'sarahlite_border_color',
			array(
				'label' => __( 'Border Color', 'sarahlite' ),
				'section' => 'colors'
			)
		)
	);

    # Footer
    $wp_customize->add_setting( 'sarahlite_footer_copyright', array(
        'default' => __( 'Your Copyright Here!', 'sarahlite' ),
        'sanitize_callback' => 'wp_kses_post'
    ));

    if ( current_user_can( 'edit_theme_options' ) ) {
        $wp_customize->add_control(
    		new WP_Customize_Control(
    			$wp_customize,
    			'sarahlite_footer_copyright',
    			array(
    				'label'      => __( 'Footer copyright text', 'sarahlite' ),
    				'section'    => 'sarahlite_new_section_footer',
    				'type'		 => 'textarea'
    			)
    		)
    	);
    }
}

add_action( 'customize_register', 'sarahlite_register_theme_customizer' );

function sarahlite_theme_style() {
	$custom_css = '';
	if ( get_theme_mod( 'sarahlite_logo_padding_top' ) ) {
		$custom_css .= '#site-name { padding-top: ' . esc_attr( get_theme_mod( 'sarahlite_logo_padding_top' ) ) . 'px; }';
	}

	if ( get_theme_mod( 'sarahlite_logo_padding_bottom' ) ) {
		$custom_css .= '#site-name { padding-bottom: ' . esc_attr( get_theme_mod( 'sarahlite_logo_padding_bottom' ) ) . 'px; }';
	}

    if ( get_theme_mod( 'sarahlite_body_color' ) ) {
		$custom_css .= '
			:root{
                --body-color: '. esc_attr( get_theme_mod( 'sarahlite_body_color' ) ) .';
            }
		';
	}

    if ( get_theme_mod( 'sarahlite_primary_color' ) ) {
		$custom_css .= '
			:root{
                --primary-color: '. esc_attr( get_theme_mod( 'sarahlite_primary_color' ) ) .';
            }
		';
	}

    if ( get_theme_mod( 'sarahlite_meta_color' ) ) {
		$custom_css .= '
			:root{
                --meta-color: '. esc_attr( get_theme_mod( 'sarahlite_meta_color' ) ) .';
            }
		';
	}

	if ( get_theme_mod( 'sarahlite_accent_color' ) ) {
		$custom_css .= '
			:root{
                --accent-color: '. esc_attr( get_theme_mod( 'sarahlite_accent_color' ) ) .';
            }
		';
	}
    
    if ( get_theme_mod( 'sarahlite_border_color' ) ) {
		$custom_css .= '
			:root{
                --border-color: '. esc_attr( get_theme_mod( 'sarahlite_border_color' ) ) .';
            }
		';
	}

	wp_add_inline_style( 'sarahlite-style', $custom_css );
}

add_action( 'wp_enqueue_scripts', 'sarahlite_theme_style', 15 );
