<?php
define( 'SARAHLITE_CORE_PATH', get_template_directory() . '/core/' );

if ( ! function_exists( 'wp_body_open' ) ) {
    function wp_body_open() {
        do_action( 'wp_body_open' );
    }
}

if ( ! function_exists( 'sarahlite_require_file' ) ) {
    /**
     * Check file exists and require
     */
    function sarahlite_require_file( $path ) {
        if ( file_exists( $path ) ) {
            require $path;
        }
    }
}

if ( ! class_exists( 'AZT_Front_End' ) ) {
    class AZT_Frond_End {
        private static $_instance = null;
        /**
    	 * Instance
    	 *
    	 * Ensures only one instance of the class is loaded or can be loaded.
    	 *
    	 * @since 1.0.0
    	 *
    	 * @access public
    	 * @static
    	 *
    	 * @return AZT_Frond_End An instance of the class.
    	 */
    	public static function instance() {
    		if ( is_null( self::$_instance ) ) {
    			self::$_instance = new self();
    		}
    		return self::$_instance;
    	}

        public function __construct() {
            add_action( 'after_setup_theme',        [ $this, 'setup_theme' ] );
            add_action( 'wp_print_footer_scripts',  [ $this, 'skip_link_focus_fix' ] );
            add_action( 'wp_enqueue_scripts',       [ $this, 'load_scripts' ] );
            add_action( 'widgets_init',             [ $this, 'register_sidebars' ] );
            add_action( 'tgmpa_register',           [ $this, 'register_required_plugins' ] );
            $this->load_files();
        }

        /**
         * Theme setup.
         */
        public function setup_theme()
        {
            // Maximum allowed width for any content in the theme, like oEmbeds and images added to posts.  https://codex.wordpress.org/Content_Width
        	global $content_width;
        	if ( ! isset( $content_width ) ) {
        		$content_width = apply_filters( 'azt_content_width', 1170 );
        	}

            load_theme_textdomain( 'sarahlite', get_template_directory() . '/languages' );
        
        	add_theme_support( 'title-tag' );
            add_theme_support( 'woocommerce' );
        	add_theme_support( 'automatic-feed-links' );
        	add_theme_support( 'post-thumbnails' );
            add_theme_support( 'responsive-embeds' );
            add_theme_support( 'wp-block-styles' );
            add_theme_support( 'html5', array( 'comment-list', 'comment-form', 'search-form', 'gallery', 'caption', 'style', 'script' ) );
            add_theme_support( 'custom-logo', array(
            	'height'      => 100,
            	'width'       => 400,
            	'flex-height' => true,
            	'flex-width'  => true
            ) );
            add_theme_support( 'custom-background', array( 'default-color' => 'f5f5f5' ) ); 
        	register_nav_menus(
                array(
                    'primary' => __( 'Primary menu', 'sarahlite' )
                )
            );
        }

        /**
         * Fix skip link focus in IE11.
         *
         * This does not enqueue the script because it is tiny and because it is only for IE11,
         * thus it does not warrant having an entire dedicated blocking script being loaded.
         *
         * @link https://git.io/vWdr2
         */
        public function skip_link_focus_fix() {
        	// The following is minified via `terser --compress --mangle -- js/skip-link-focus-fix.js`.
        	?>
        	<script>
        	/(trident|msie)/i.test(navigator.userAgent)&&document.getElementById&&window.addEventListener&&window.addEventListener("hashchange",function(){var t,e=location.hash.substring(1);/^[A-z0-9_-]+$/.test(e)&&(t=document.getElementById(e))&&(/^(?:a|select|input|button|textarea)$/i.test(t.tagName)||(t.tabIndex=-1),t.focus())},!1);
        	</script>
        	<?php
        }

        /**
         * Register & Enqueue Styles / Scripts
         */
        public function load_scripts() {
            // Google Fonts
            $fonts_url  = '';
            $Lato       = _x( 'on', 'Lato font: on or off', 'sarahlite' );
            $Montserrat = _x( 'on', 'Montserrat: on or off', 'sarahlite' );  

            if ( 'off' !== $Montserrat || 'off' !== $Lato )
            {
                $font_families = array();
                if ( 'off' !== $Lato ) $font_families[] = 'Lato:400,400i';
                if ( 'off' !== $Montserrat) $font_families[] = 'Montserrat:300,400,500,700';

                $query_args = array(
                    'family' => urlencode( implode( '|', $font_families ) ),
                    'subset' => urlencode( 'latin,latin-ext' )
                );

                $fonts_url = add_query_arg( $query_args, '//fonts.googleapis.com/css' );
            }

            wp_enqueue_style( 'google-fonts', esc_url_raw($fonts_url), array(), null );

            # CSS
            wp_enqueue_style( 'bootstrap-min', get_template_directory_uri() . '/libs/bootstrap/bootstrap.min.css' );
            wp_enqueue_style( 'fontawesome', get_template_directory_uri() . '/libs/fontawesome/css/all.min.css' );
            wp_enqueue_style( 'owl-carousel', get_template_directory_uri() . '/libs/owl/owl.carousel.min.css' );
            wp_enqueue_style( 'sarahlite-style', get_template_directory_uri() . '/style.css', array(), rand(0, 9999) );
            wp_enqueue_style( 'sarahlite-site-menu', get_template_directory_uri() . '/assets/css/site-menu.css', array(), rand(0, 9999) );

            # JS
        	wp_enqueue_script( 'jquery' );
            wp_enqueue_script( 'owl-carousel', get_template_directory_uri() . '/libs/owl/owl.carousel.min.js' );
            wp_enqueue_script( 'sarahlite-scripts', get_template_directory_uri() . '/assets/js/scripts.js', array(), false, true );

            if ( is_singular() && get_option( 'thread_comments' ) ) {
                wp_enqueue_script( 'comment-reply' );
            }
        }

        /**
         * Register Sidebar
         */
        function register_sidebars() {
            if ( function_exists( 'register_sidebar' ) ) {
            	register_sidebar( array(
            		'name'            => __( 'Sidebar', 'sarahlite' ),
            		'id'              => 'sidebar',
            		'before_widget'   => '<div id="%1$s" class="widget %2$s">',
            		'after_widget'    => '</div>',
            		'before_title'    => '<h2 class="widget-title">',
            		'after_title'     => '</h2>',
                    'description'     => __( 'Display widgets for blog, archive and single post.', 'sarahlite' )
            	));
        
                register_sidebar(array(
            		'name'            => __( 'Instagram Footer', 'sarahlite' ),
            		'id'              => 'footer-sidebar',
            		'before_widget'   => '<div id="%1$s" class="widget %2$s">',
            		'after_widget'    => '</div>',
            		'before_title'    => '<h2 class="widget-title"><span>',
            		'after_title'     => '</span></h2>',
                    'description'     => __( 'Use the "Instagram" widget here. IMPORTANT: For best result set number of photos to 6.', 'sarahlite' )
            	));
            }
        }
        
        /**
         * Load files
         */
        public function load_files() {
            /**
             * Theme Function
             */
            sarahlite_require_file( SARAHLITE_CORE_PATH . 'theme-functions.php' );

            /**
             * Theme Hooks
             */
            sarahlite_require_file( SARAHLITE_CORE_PATH . 'theme-hooks.php' );

            /**
             * Theme Customizer
             */
            sarahlite_require_file( SARAHLITE_CORE_PATH . 'theme-customizer.php' );
        }
    }
    
    AZT_Frond_End::instance();
}
